#
# antirefspam.rb 
#
# Copyright (c) 2004-2005 T.Shimomura <redbug@netlife.gr.jp>
# You can redistribute it and/or modify it under GPL2.
# Please use version 1.0.0 (not 1.0.0G) if GPL doesn't want to be forced on me.
#

@antispamref_html_antispamref = <<-TEXT
	<h3>󥯸¤򤫤</h3>
	<p>
	ե饹ѥɤˡrefererФ¤򤫤뤳ȤǤޤ
	</p>
	TEXT

@antispamref_html_disable = <<-TEXT
	refererФ¤򤫤ʤ
	TEXT

@antispamref_html_myurl = <<-TEXT
	<h3>Ƥλ</h3>
	<p>
	ȥåץڡURL(#{h(if @conf.index_page.empty? then "̤" else @conf.index_page end)})URL(#{h(if @conf.base_url.empty? then "" else @conf.base_url end)})ʳ˥ȤƵƤURLꤷޤ
	ɽѲǽǤ
	</p>
	TEXT

@antispamref_html_proxy = <<-TEXT
	<h3>HTTPץСλ</h3>
	<p>
	Υץ饰ϡ󥯸˻ꤵ줿 HTTP С˥ơ󥯸HTML ޤ
	Υ HTTP ץͳɬפϰʲꤷƤ<br>
	 : server : proxy.foo.com  port : 8080
	</p>
	TEXT

@antispamref_html_trustedurl = <<-TEXT
	<h3>ꤹ󥯸λ</h3>
	<p>
	ҥȡ
	<ul>
	<li>ԤˣĤ URL 񤤤Ƥ</li>
	<li>\#ǻϤޤԡԤ̵뤵ޤ</li>
	<li>"ꤹ󥯸" ϣʳʬƥåޤ</li>
	<ul>
	<li>ܤϡɽȤäƤʤΤȤƥåޤ񤫤줿 URL 󥯸
	    ޤޤƤСꤹ󥯸Ȥߤʤޤ<br>
	     : 󥯸 http://www.foo.com/bar/  http://www.foo.com/baz/ ξ硢
	         URL ˤ http://www.foo.com/ Ƚ񤱤Ф褤</li>
	<li>ܤϡɽȤäƤΤȤƥåޤξ硢URL  : ()  / (å) 
	    ǥפޤɽȤ硢󥯸Τ˥ޥåɬפդƤ<br>
	     : 󥯸 http://aaa.foo.com/bar/  http://bbb.foo.com/baz/ ξ硢
	         URL ˤ http://\\w+\.foo\.com/.* Ƚ񤱤Ф褤</li>
	</ul>
	</ul>
	</p>
	TEXT

@antispamref_html_checkreftable = <<-TEXT
	֥󥯸ִꥹȡפ˥ޥå󥯸ꤹ롣
	TEXT


@antispamref_html_comment = <<-TEXT
	<h3>ĥåߤ¤򤫤</h3>
	<p>
	ȥѥɤˡȤФ͡¤򤫤뤳ȤǤޤ
	</p>
	TEXT

@antispamref_html_comment_kanaonly = <<-TEXT
	ĥåߤˤҤ餬/ʤޤޤƤʤϵݤ롣
	TEXT

@antispamref_html_comment_maxsize = <<-TEXT
	ĥåʸĹξ¤ʸ
	TEXT

@antispamref_html_comment_ngwords = <<-TEXT
	ʲñ줬ĥåߤ˴ޤޤƤϵݤ<br>
	ɽѲǽǤɽʣԥ⡼ɤưޤ
	ɽƬ \/ ϤĤʤǤ<br>
	TEXT

@antispamref_html_faq = <<-TEXT
	<h3>FAQ</h3>
	<p>
	¾ǿFAQ <a href="http://www.netlife.gr.jp/redbug/diary/?date=20041018\#p02">http://www.netlife.gr.jp/redbug/diary/?date=20041018\#p02</a> 򻲾ȤƤ
	</p>
	TEXT

